# [ADR-xxx] <!-- short title of solved problem and solution -->

- **Status**:
  <!-- proposed -->
  <!-- rejected -->
  <!-- accepted -->
  <!-- deprecated -->
  <!-- superseded by [ADR-xxx](./xxx.md) -->
- **Deciders**: <!-- @github-user -->

## Context and problem statement

<!--
Describe the context and problem statement, e.g., in free form using two to
three sentences. You may want to articulate the problem in form of a question.
-->

<!--
### Issues with existing set-up

Summary of problems with the existing design, possibly with some snippets.
-->

<!--
### Technical story

If available, list and link related issues, PRs, or ADRs that led up to this
ADR:

- [#000](https://github.com/ComPWA/ampform/issues/000)
- [#001](https://github.com/ComPWA/ampform/issues/001)
-->

## Decision drivers

<!--
### Solution requirements

1. Requirement 1
2. Requirement 2
-->

## Considered solutions

<!--
Solutions can be illustrated with Jupyter notebooks or MyST files in a
subfolder. They should only factually illustrate design and implementation: the
discussion should take place in the main document.

To include documents in a sub-folder, use a toctree:

```{toctree}
xxx/option1
xxx/option2
```
-->

## Evaluation

### Pros and Cons

<!--
List some advantages and disadvantages of each of the implementations, possibly
with links (using e.g. {ref} or {doc}) to the proposed solutions.

#### Option 1

- **Positive**:
  1.
  2.
- **Negative**:
  1.
  2.

#### Option 2

- **Positive**:
  1.
  2.
- **Negative**:
  1.
  2.
-->

<!--
### Requirement evaluation

See [requirements](#solution-requirements).

|          | 1   | 2   | 3   | ... |
| -------- | --- | --- | --- | --- |
| Option 1 |     |     |     |     |
| Option 2 |     |     |     |     |
| ...      |     |     |     |     |
-->

## Decision outcome

<!--
Chosen option: "[option 1]", because [justification. e.g., only option, which
meets k.o. criterion decision driver | which resolves force force | … | comes
out best (see below)].
-->

<!--
### Positive consequences

- [e.g., improvement of quality attribute satisfaction, follow-up decisions
  required, …]
- …

### Negative consequences

- [e.g., compromising quality attribute, follow-up decisions required, …]
- …
-->
